ZipPlusCommitment

Struct ZipPlusCommitment 

pub struct ZipPlusCommitment {
    pub root: MtHash,
    pub batch_size: usize,
}
The compact commitment to a multilinear polynomial, consisting of only the Merkle roots, to be sent to the verifier.

Fields

root: MtHash

Roots of the merkle tree of entire matrix

batch_size: usize