pub struct ZipPlusHint<R> {
pub cw_matrices: Vec<DenseRowMatrix<R>>,
pub merkle_tree: MerkleTree,
}Expand description
Full data of zip commitment to a multilinear polynomial, including encoded rows and Merkle tree, kept by the prover for the testing phase.
Fields
cw_matrices: Vec<DenseRowMatrix<R>>The encoded rows of the polynomial matrix representation, referred to as “u-hat” in the Zinc paper
merkle_tree: MerkleTreeMerkle trees of entire matrix
Implementations
Sourceimpl<R> ZipPlusHint<R>
impl<R> ZipPlusHint<R>
pub fn new( cw_matrices: Vec<DenseRowMatrix<R>>, merkle_tree: MerkleTree, ) -> ZipPlusHint<R>