pub struct ZipPlusCommitment {
pub root: MtHash,
pub batch_size: usize,
}Expand description
The compact commitment to a multilinear polynomial, consisting of only the Merkle roots, to be sent to the verifier.
Fields
root: MtHashRoots of the merkle tree of entire matrix
batch_size: usizeTrait Implementations
Sourceimpl Clone for ZipPlusCommitment
impl Clone for ZipPlusCommitment
Sourcefn clone(&self) -> ZipPlusCommitment
fn clone(&self) -> ZipPlusCommitment
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ZipPlusCommitment
impl Debug for ZipPlusCommitment
Sourceimpl Default for ZipPlusCommitment
impl Default for ZipPlusCommitment
Sourcefn default() -> ZipPlusCommitment
fn default() -> ZipPlusCommitment
Returns the “default value” for a type. Read more
Sourceimpl GenTranscribable for ZipPlusCommitment
impl GenTranscribable for ZipPlusCommitment
Sourcefn read_transcription_bytes_exact(bytes: &[u8]) -> Self
fn read_transcription_bytes_exact(bytes: &[u8]) -> Self
Creates a new instance from a byte buffer.
The buffer must be exactly the expected length.
Sourcefn write_transcription_bytes_exact(&self, buf: &mut [u8])
fn write_transcription_bytes_exact(&self, buf: &mut [u8])
Transcribes the current instance into a byte buffer.
The buffer must be exactly the expected length.
Sourceimpl PartialEq for ZipPlusCommitment
impl PartialEq for ZipPlusCommitment
impl Eq for ZipPlusCommitment
impl StructuralPartialEq for ZipPlusCommitment